@@ -1,9 +1,10 @@
 /*
-  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2018 Montel Laurent <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
 
   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -15,15 +16,14 @@
   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
-#ifndef RESOUCEREADCONFIGFILE_H
-#define RESOUCEREADCONFIGFILE_H
+#ifndef RESOURCEREADCONFIGFILE_H
+#define RESOURCEREADCONFIGFILE_H
 
 #include <KConfigGroup>
 #include <QString>
 #include "mailcommon_export.h"
 
-namespace MailCommon
-{
+namespace MailCommon {
 class ResourceReadConfigFilePrivate;
 class MAILCOMMON_EXPORT ResourceReadConfigFile
 {
@@ -37,4 +37,4 @@ private:
 };
 }
 
-#endif // RESOUCEREADCONFIGFILE_H
+#endif // RESOURCEREADCONFIGFILE_H
